<?php

declare(strict_types=1);

namespace FiloBlu\Checkproducts\Model;

use Magento\Catalog\Api\Data\ProductInterface;
use Psr\Log\LoggerInterface;

/**
 *
 */
class Collector implements CollectorInterface
{
    /**
     * @var array
     */
    protected $data = [];
    /**
     * @var \Psr\Log\LoggerInterface
     */
    private $logger;

    /**
     * @param \Psr\Log\LoggerInterface $logger
     */
    public function __construct(LoggerInterface  $logger)
    {
        $this->logger = $logger;
    }

    /**
     * @param \Magento\Catalog\Api\Data\ProductInterface $product
     * @param $key
     * @return void
     */
    public function collect(ProductInterface $product, $key)
    {
        $sku = $product->getSku();
        $store = $product->getStore();

        if(!$sku) {
            $this->logger->warning(__CLASS__ . " : Invalid sku '$sku'");
            return;
        }
        if(!$store) {
            $this->logger->warning(__CLASS__ . ' : Invalid store');
            return;
        }

        if(!$store->getData('code')) {
            $this->logger->warning(__CLASS__ . ' : Invalid store code');
            return;
        }

        if(!$key) {
            $this->logger->warning(__CLASS__ . ' : Invalid key provided');
            return;
        }

        $this->data[$product->getSku()][$product->getStore()->getData('code')][(string)$key] = false;
    }

    /**
     * @return array
     */
    public function getCollectedData()
    {
        return $this->data;
    }

    public function reset()
    {
        $this->data = [];
    }
}
